Module crypto

Module crypto 

This is the library part that handles all encryption and decryption

Structs

GpgMe
Used when the user configures gpgme to be used as a pgp backend.
GpgMeKey
A key gotten from gpgme
Sequoia
If the user selects to use sequoia as their pgp implementation.
SequoiaKey
A pgp key produced with sequoia.

Enums

CryptoImpl
The different pgp implementations we support
Error
An enum that contains the different types of errors that the library returns as part of Result’s.
FindSigningFingerprintStrategy
The strategy for finding the gpg key to sign with can either be to look at the git config, or ask gpg.
VerificationError
The different types of errors that can occur when doing a signature verification

Traits

Crypto
All operations that can be done through pgp, either with gpgme or sequoia.
Key
Models the interactions that can be done on a pgp key

Functions

slice_to_20_bytes
Intended for usage with slices containing a v4 fingerprint.

Type Aliases

Result
Convenience type for Results