pub struct Comment {
pub pre_comment: Option<String>,
pub post_comment: Option<String>,
}Expand description
Describes a comment around a gpg id / fingerprint. See this commit for source: https://git.zx2c4.com/password-store/commit/?id=a271b43cbd76cc30406202c49041b552656538bd
Fields
pre_comment: Option<String>The comment field from the .gpg-id file, above the user fingerprint not including the leading ‘#’ characters.
post_comment: Option<String>The comment field from the .gpg-id file, after the user fingerprint not including the leading ‘#’ characters.